Cidade class

Classe que representa uma cidade.

Esta classe contém informações sobre uma cidade, como se é capital, o código IBGE, o código SIAFI, o DDD, o fuso horário e o estado ao qual a cidade pertence.

Inheritance
Implemented types

Properties

capital → bool
Indica se a cidade é capital do estado.
final
ddd → int
O DDD da cidade.
final
estado → Estado
O estado ao qual a cidade pertence.
no setter
hashCode → int
The hash code for this object.
no setteroverride
ibge → int
O código IBGE da cidade.
final
isValid → bool
no setterinherited
latitude → double
finalinherited
latitudeInRad → double
no setterinherited
longitude → double
finalinherited
longitudeInRad → double
no setterinherited
nome → String
O nome da cidade.
final
regiao → Regiao
A região do estado ao qual a cidade pertence.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siafi → int
O código SIAFI da cidade.
final
timeZone → String
O fuso horário da cidade.
final

Methods

compareTo(Cidade other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
round({int decimals = 6}) → LatLng
inherited
toJson() → Map<String, dynamic>
Converte a instância de Cidade para um mapa JSON.
override
toSexagesimal() → String
Converts lat/long values into sexagesimal
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

pegarCidades → Future<List<Cidade>>
Obtém uma lista de todas as cidades.
no setter

Static Methods

pegar(dynamic nomeCidadeOuIBGE, [dynamic nomeOuUFOuIBGE]) → Future<Cidade?>
Obtém uma cidade a partir do nome, UF ou IBGE e estado.
pesquisar(String nomeCidadeOuIBGE, [String nomeOuUFOuIBGE = ""]) → Future<Iterable<Cidade>>
Pesquisa uma cidade no Brasil todo ou em algum estado especifico se nomeOuUFOuIBGE for especificado.