EdgeInsetsExtensionsForNum extension

Extension methods for num to create EdgeInsets from different directions.

on

Properties

allAround → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with all four offsets set to the current value.
no setter
fromBottom → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with only bottom offset set to the current value.
no setter
fromHorizontal → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with both left and right offsets set to the current value.
no setter
fromLeft → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with only left offset set to the current value.
no setter
fromRight → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with only right offset set to the current value.
no setter
fromTop → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with only top offset set to the current value.
no setter
fromVertical → EdgeInsets

Available on num, provided by the EdgeInsetsExtensionsForNum extension

Creates EdgeInsets with both top and bottom offsets set to the current value.
no setter