DirectoryExtensionPlus extension

on

Properties

count → Future<int>

Available on Directory, provided by the DirectoryExtensionPlus extension

Asynchronously gets the count of items in the list.
no setter
countSync → int

Available on Directory, provided by the DirectoryExtensionPlus extension

A getter that returns the count of all elements in the list synchronously.
no setter
listAll → Future<Iterable<FileSystemEntity>>

Available on Directory, provided by the DirectoryExtensionPlus extension

Returns a Future that completes with an Iterable of FileSystemEntity objects representing the contents of the directory. The listing is not recursive.
no setter
listAllRecursive → Future<Iterable<FileSystemEntity>>

Available on Directory, provided by the DirectoryExtensionPlus extension

Asynchronously lists all files and directories recursively.
no setter
listAllRecursiveSync → List<FileSystemEntity>

Available on Directory, provided by the DirectoryExtensionPlus extension

Returns a list of all file system entities within the current directory and its subdirectories, recursively. This method performs a synchronous operation to retrieve the list of entities.
no setter
listAllSync → List<FileSystemEntity>

Available on Directory, provided by the DirectoryExtensionPlus extension

Returns a list of all file system entities in the current directory.
no setter
listDirectories → Future<Iterable<Directory>>

Available on Directory, provided by the DirectoryExtensionPlus extension

Asynchronously lists all directories within the current directory.
no setter
listDirectoriesRecursive → Future<Iterable<Directory>>

Available on Directory, provided by the DirectoryExtensionPlus extension

Asynchronously retrieves a list of directories recursively.
no setter
listDirectoriesRecursiveSync → Iterable<Directory>

Available on Directory, provided by the DirectoryExtensionPlus extension

An extension property that recursively lists all directories in the current directory.
no setter
listDirectoriesSync → Iterable<Directory>

Available on Directory, provided by the DirectoryExtensionPlus extension

Returns an iterable of directories from the list of all file system entities.
no setter
listFiles → Future<Iterable<File>>

Available on Directory, provided by the DirectoryExtensionPlus extension

Asynchronously retrieves a list of all files in the current directory.
no setter
listFilesRecursive → Future<Iterable<File>>

Available on Directory, provided by the DirectoryExtensionPlus extension

Asynchronously retrieves a list of all files recursively from the current directory.
no setter
listFilesRecursiveSync → Iterable<File>

Available on Directory, provided by the DirectoryExtensionPlus extension

Returns an iterable of all files found recursively within the directory.
no setter
listFilesSync → Iterable<File>

Available on Directory, provided by the DirectoryExtensionPlus extension

Returns an iterable of files from the list of all entities in the directory.
no setter

Methods

copy(Directory to, [bool skipTopDirectory = false]) → Future<Directory>

Available on Directory, provided by the DirectoryExtensionPlus extension

Available on Directory, provided by the DirectoryExtensionPlus extension