Brand class

Inheritance
Available extensions

Constructors

Brand(String? assetName, {Key? key, double? size = 35.0, ColorFilter? colorFilter})

Properties

alignment AlignmentGeometry
How to align the picture within its parent widget.
finalinherited
allowDrawingOutsideViewBox bool
If true, will allow the SVG to be drawn outside of the clip boundary of its viewBox.
finalinherited
bytesLoader → BytesLoader
The BytesLoader used to resolve the SVG.
finalinherited
clipBehavior Clip
The content will be clipped (or not) according to this option.
finalinherited
colorFilter ColorFilter?
The color filter, if any, to apply to this widget.
finalinherited
errorBuilder → SvgErrorWidgetBuilder?
Widget displayed while the target image failed loading.
finalinherited
excludeFromSemantics bool
Whether to exclude this picture from semantics.
finalinherited
fit BoxFit
How to inscribe the picture into the space allocated during layout. The default is BoxFit.contain.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
height double?
If specified, the height to use for the SVG. If unspecified, the SVG will take the height of its parent.
finalinherited
imageBuilder → SvgImageWidgetBuilder?
A builder that wraps the successfully loaded SVG widget.
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
matchTextDirection bool
If true, will horizontally flip the picture in TextDirection.rtl contexts.
finalinherited
placeholderBuilder WidgetBuilder?
The placeholder to use while fetching, decoding, and parsing the SVG data.
finalinherited
renderingStrategy → RenderingStrategy
Widget rendering strategy used to balance flexibility and performance.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String?
The Semantics.label for this picture.
finalinherited
text string

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as string
no setter
texts Iterable<string>

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as list of string
no setter
width double?
If specified, the width to use for the SVG. If unspecified, the SVG will take the width of its parent.
finalinherited

Methods

alignAtBottomCenter({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom center of its parent.
alignAtBottomLeft({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom left of its parent.
alignAtBottomRight({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom right of its parent.
alignAtCenter({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center of its parent.
alignAtCenterLeft({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center left of its parent.
alignAtCenterRight({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center right of its parent.
alignAtLERP(Alignment a, Alignment b, double t, {Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at a linear interpolation between two alignments.
alignAtTopCenter({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top center of its parent.
alignAtTopLeft({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top left of its parent.
alignAtTopRight({Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top right of its parent.
alignXY(double x, double y, {Key? key, double? heightFactor, double? widthFactor}) Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at a specific x and y coordinate within its parent.
applyShimmer({bool enable = true, Color? baseColor, Color? highlightColor}) Widget

Available on Widget, provided by the ShimmerEffect extension

blurEffect([double sigmaX = 5, double sigmaY = 5, TileMode tileMode = TileMode.clamp]) Widget

Available on Widget, provided by the WidgetExt extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) Expanded

Available on Widget, provided by the ExpandedExtension extension

flexible({int flex = 1}) Flexible

Available on Widget, provided by the FlexibleExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(void function()?, {bool ink = false}) Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

onLongPress(void function()?, {bool ink = false}) Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

onTap(void function()?, {bool ink = false}) Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

paddingAll(double value, {Key? key}) Padding

Available on Widget, provided by the PaddingX extension

paddingFromViewPadding(ViewPadding padding, double devicePixelRatio, {Key? key}) Padding

Available on Widget, provided by the PaddingX extension

paddingLTRB(double left, double top, double right, double bottom, {Key? key}) Padding

Available on Widget, provided by the PaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0, Key? key}) Padding

Available on Widget, provided by the PaddingX extension

paddingSymmetric({double vertical = 0.0, double horizontal = 0.0, Key? key}) Padding

Available on Widget, provided by the PaddingX extension

positionBottom({Key? key, required double bottom, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLeft({Key? key, required double left, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLR({Key? key, required double left, required double right, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLRTB({Key? key, required double top, required double bottom, required double left, required double right, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

positionRight({Key? key, required double right, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

positionTB({Key? key, required double top, required double bottom, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

positionTop({Key? key, required double top, double? width, double? height}) Positioned

Available on Widget, provided by the PositionedExtensions extension

setOpacity({required double opacity}) Opacity

Available on Widget, provided by the OpacityExtension extension

toCenter() Center

Available on Widget, provided by the CenterExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
withTooltip(String message, {Decoration? decoration, double? height, bool? preferBelow, EdgeInsetsGeometry? padding, TextStyle? textStyle, Duration? waitDuration, EdgeInsetsGeometry? margin}) Widget

Available on Widget, provided by the WidgetsExtension extension

wrapIf(bool test, Widget func(Widget wrappedChild)) Widget

Available on Widget, provided by the WidgetExt extension

wrap a widget using a Function if test is true

Operators

operator ==(Object other) bool
The equality operator.
inherited