InternalIterableSorter<TValue, TKey> class

This class is created by calls to Iterable.orderBy (and related) and isn't intended to be instantiated directly.

Inheritance

Constructors

InternalIterableSorter(TKey keySelector(TValue), EqualityComparer<TKey>? comparer, bool descending, IterableSorter<TValue>? next)

Properties

comparer ↔ EqualityComparer<TKey>
getter/setter pair
descending ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ List<TKey>?
getter/setter pair
keySelector ↔ TKey Function(TValue)
getter/setter pair
next ↔ IterableSorter<TValue>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareKeys(int idx1, int idx2) → int
override
computeKeys(List<TValue> elements, int count) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quickSort(List<int> map, int left, int right) → void
inherited
sort(List<TValue> elements, int count) → List<int>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited