IterableSorter<T> class abstract

Constructors

IterableSorter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareKeys(int idx1, int idx2) → int
computeKeys(List<T> elements, int count) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quickSort(List<int> map, int left, int right) → void
sort(List<T> elements, int count) → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited