SelectExtension<T> extension

on

Methods

select<TResult>(TResult selector(T element, int index)) Iterable<TResult>

Available on Iterable<T>, provided by the SelectExtension extension

Applies a mapping function to the elements in the iterable, including the index where each element is found.