platform/platform library

Properties

isAndroid → bool
Checks if the platform is Android.
no setter
isApple → bool
Checks if the platform is Apple (iOS or macOS).
no setter
isDesktop → bool
Checks if the platform is a desktop (macOS, Windows, or Linux).
no setter
isFuchsia → bool
Checks if the platform is Fuchsia.
no setter
isGoogle → bool
Checks if the platform is a Google platform (Android or Fuchsia).
no setter
isIOS → bool
Checks if the platform is iOS.
no setter
isLinux → bool
Checks if the platform is Linux.
no setter
isMacOS → bool
Checks if the platform is macOS.
no setter
isMobile → bool
Checks if the platform is a mobile platform (iOS or Android).
no setter
isNativeAndroid → bool
Checks if the platform is native Android (not web).
no setter
isNativeApple → bool
Checks if the platform is native Apple (not web).
no setter
isNativeDesktop → bool
Checks if the platform is native desktop (not web).
no setter
isNativeFuchsia → bool
Checks if the platform is native Fuchsia (not web).
no setter
isNativeGoogle → bool
Checks if the platform is native Google (not web).
no setter
isNativeIOS → bool
Checks if the platform is native iOS (not web).
no setter
isNativeLinux → bool
Checks if the platform is native Linux (not web).
no setter
isNativeMacOS → bool
Checks if the platform is native macOS (not web).
no setter
isNativeMobile → bool
Checks if the platform is native mobile (not web).
no setter
isNativeWindows → bool
Checks if the platform is native Windows (not web).
no setter
isPlatformDarkMode → bool
Checks if the platform is in dark mode.
no setter
isPlatformLightMode → bool
Checks if the platform is in light mode.
no setter
isWeb → bool
Checks if the platform is web.
no setter
isWindows → bool
Checks if the platform is Windows.
no setter