SQLResponseOf<T extends Object?> class

Implementers

Constructors

SQLResponseOf({required bool hasData, required String sql, required String status, required T? data, required bool hasError, required String dataSetType, String message = ""})
SQLResponseOf.empty({string? message, string dataSetType = "table", string? sql})
factory
SQLResponseOf.error({string? message, string dataSetType = "table", string? sql})
factory
SQLResponseOf.fromData(T data, {string sql = "", string dataSetType = "table"})
factory
SQLResponseOf.fromJson(JsonMap json)
factory

Properties

data → T?
final
dataSetType → String
final
error → String
no setter
hasData → bool
final
hasError → bool
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
final
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → JsonMap
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited