Telefone class

Classe que representa um número de telefone.

Constructors

Telefone([dynamic numero])
Construtor da classe Telefone.

Properties

completo → String
Retorna o número de telefone completo, incluindo o DDD.
no setter
completoMascara → String
Retorna o número de telefone completo, incluindo o DDD, formatado com máscara.
no setter
ddd ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
numero → String
Retorna o número de telefone.
no setter
numeroMascara → String
Retorna o número de telefone formatado com máscara.
no setter
prefixo ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sufixo ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Retorna uma representação em string do número de telefone.
override

Operators

operator ==(Object other) → bool
Compara se dois números de telefone são iguais.
override