TextEditingValueExtensions extension

on

Properties

countLines → int

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets the number of lines in the text.
no setter
countWords → int

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

no setter
currentLineIndex → int

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets the index of the current line where the cursor is located.
no setter
currentLineText → string

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets or sets the current line where the cursor is located.
no setter
currentWord → string

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets the current word where the cursor is located.
no setter
currentWordIndex → int

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets the index of the current word where the cursor is located.
no setter
lines → Iterable<string>

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets all lines in the text.
no setter
words → Iterable<string>

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets all words in the text.
no setter

Methods

lineAt(int index) → string

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets the line at the specified index.
wordAt(int index) → string

Available on TextEditingValue, provided by the TextEditingValueExtensions extension

Gets the word at the specified index.