Validator class abstract interface

The Validator class is used to implement validation logic in other classes.

Implementers
Available extensions

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → string
A string representation of this object.
inherited
validate() → Iterable<String>
Validates the current instance and returns a list of error messages if the instance is invalid.
validateOrThrow<T extends Exception>([T exception(Iterable<String> errors)?]) → void

Available on Validator, provided by the ValidatorClassExtensions extension

Validates the object and throws an exception if there are any errors.

Operators

operator ==(Object other) → bool
The equality operator.
inherited