WidgetExt extension

on

Properties

text → string

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as string
no setter
texts → Iterable<string>

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as list of string
no setter

Methods

blurEffect([double sigmaX = 5, double sigmaY = 5, TileMode tileMode = TileMode.clamp]) → Widget

Available on Widget, provided by the WidgetExt extension

wrapIf(bool test, Widget func(Widget wrappedChild)) → Widget

Available on Widget, provided by the WidgetExt extension

wrap a widget using a Function if test is true