LicensePlate class abstract

Inheritance
Implementers
Available extensions

Constructors

LicensePlate(String plate, {Key? key, double? width, double? height, String? locality = 'BRASIL', PlateCategory? category, Color? backgroundColor, Color? borderColor, Color? textColor, bool compact = false})
const

Properties

backgroundColor → Color?
final
borderColor → Color?
final
category → PlateCategory?
final
compact → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locality → String?
final
plate → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → string

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as string
no setter
textColor → Color?
final
texts → Iterable<string>

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as list of string
no setter
width → double?
final

Methods

alignAtBottomCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom center of its parent.
alignAtBottomLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom left of its parent.
alignAtBottomRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom right of its parent.
alignAtCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center of its parent.
alignAtCenterLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center left of its parent.
alignAtCenterRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center right of its parent.
alignAtLERP(Alignment a, Alignment b, double t, {Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at a linear interpolation between two alignments.
alignAtTopCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top center of its parent.
alignAtTopLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top left of its parent.
alignAtTopRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top right of its parent.
alignXY(double x, double y, {Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at a specific x and y coordinate within its parent.
applyShimmer({bool enable = true, Color? baseColor, Color? highlightColor}) → Widget

Available on Widget, provided by the ShimmerEffect extension

blurEffect([double sigmaX = 5, double sigmaY = 5, TileMode tileMode = TileMode.clamp]) → Widget

Available on Widget, provided by the WidgetExt extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Expanded

Available on Widget, provided by the ExpandedExtension extension

flexible({int flex = 1}) → Flexible

Available on Widget, provided by the FlexibleExtension extension

getBackgroundColor() → Color
getBorderColor() → Color
getTextColor() → Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(void function()?, {bool ink = false}) → Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

onLongPress(void function()?, {bool ink = false}) → Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

onTap(void function()?, {bool ink = false}) → Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

paddingAll(double value, {Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingFromViewPadding(ViewPadding padding, double devicePixelRatio, {Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingLTRB(double left, double top, double right, double bottom, {Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0, Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingSymmetric({double vertical = 0.0, double horizontal = 0.0, Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

positionBottom({Key? key, required double bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLeft({Key? key, required double left, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLR({Key? key, required double left, required double right, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLRTB({Key? key, required double top, required double bottom, required double left, required double right, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionRight({Key? key, required double right, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionTB({Key? key, required double top, required double bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionTop({Key? key, required double top, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

setOpacity({required double opacity}) → Opacity

Available on Widget, provided by the OpacityExtension extension

toCenter() → Center

Available on Widget, provided by the CenterExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withTooltip(String message, {Decoration? decoration, double? height, bool? preferBelow, EdgeInsetsGeometry? padding, TextStyle? textStyle, Duration? waitDuration, EdgeInsetsGeometry? margin}) → Widget

Available on Widget, provided by the WidgetsExtension extension

wrapIf(bool test, Widget func(Widget wrappedChild)) → Widget

Available on Widget, provided by the WidgetExt extension

wrap a widget using a Function if test is true

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

categoryFromIdentifier(String value) → PlateCategory?
categoryFromPlate(String plate, dynamic value) → PlateCategory?
convertToMercosulPlate(String? oldPlate) → String
Converts an old plate String to the Mercosul standard.
convertToThreeLettersPlate(String? newPlate) → String
Converts a String from Mercosul license plate to the old standard.
create(String plate, {double? width, double? height, String? locality, PlateCategory? category, Color? backgroundColor, Color? borderColor, Color? textColor, Color? topBarColor, bool compact = false}) → LicensePlate
Create a TwoLettersPlate, ThreeLettersPlate or MercosulPlate from String. The plate type is auto-selected by category or by format of String. If category is not provided, the plate type is auto-selected by the format of plate. If category is not provided and plate is not a valid plate number, return a MercosulPlate with MercosulPlateCategory. Colors can be customized by passing the backgroundColor, borderColor, textColor and topBarColor parameters.
isValidPlate(String plate) → bool
validate if String is a valid plate number