TwoLettersPlate class

A widget that prints a license plate in the "two letters pattern" on the screen.

Inheritance
Implemented types
Available extensions

Constructors

TwoLettersPlate(String plate, {Key? key, double? width, double? height, bool showLocality = true, String locality = 'BRASIL', TwoLettersPlateCategory category = TwoLettersPlateCategory.particular, Color? backgroundColor, Color? borderColor, Color? textColor, bool compact = false})
Class constructor. To obtain the original aspect ratio of a real license plate, only provide a value for width OR height, so it will keep the original proportion automatically. If a value is provided for these two properties, then the original aspect ratio will not be take in account. If neither are provided, the value of _defaultWidth will be used.
const

Properties

backgroundColor → Color?
final
borderColor → Color?
final
category → TwoLettersPlateCategory
The plate's category which determines the default color set
final
compact → bool
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
The height that the whole widget will take. If left null, then the original proportion factor will be used to calculate this value from the width.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locality → String
The city name and state acronym printed in locality header
final
plate → String
The letters and numbers drawn in the licence plate
final
realHeight → double
Evaluates the real height that will be considered while drawing the widget. If a height value was explicitly passed to object's constructor, then this value will be used. Otherwise, it infers a value for height from the width property, consering the original proportional factor.
no setter
realWidth → double
Evaluates the width value that will be used to draw the widget. If a value is passed to the constructor, then this value will be used. Otherwise, it checks if a value has been passed to height and calculates the width using the original proportion factor. If both width and height are nulls, then the value setted for _defaultWidth will be used.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLocality → bool
Whether to show the locality header
final
text → string

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as string
no setter
textColor → Color?
final
texts → Iterable<string>

Available on Widget, provided by the WidgetExt extension

get all the Text children in the widget tree and return their text as list of string
no setter
width → double?
The width that the whole widget will take. If null, the width value will be infered from the height value. If height is null, then the _defaultWidth value will be considered.
final

Methods

alignAtBottomCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom center of its parent.
alignAtBottomLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom left of its parent.
alignAtBottomRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the bottom right of its parent.
alignAtCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center of its parent.
alignAtCenterLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center left of its parent.
alignAtCenterRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the center right of its parent.
alignAtLERP(Alignment a, Alignment b, double t, {Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at a linear interpolation between two alignments.
alignAtTopCenter({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top center of its parent.
alignAtTopLeft({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top left of its parent.
alignAtTopRight({Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at the top right of its parent.
alignXY(double x, double y, {Key? key, double? heightFactor, double? widthFactor}) → Align

Available on Widget, provided by the AlignExtensions extension

Aligns the widget at a specific x and y coordinate within its parent.
applyShimmer({bool enable = true, Color? baseColor, Color? highlightColor}) → Widget

Available on Widget, provided by the ShimmerEffect extension

blurEffect([double sigmaX = 5, double sigmaY = 5, TileMode tileMode = TileMode.clamp]) → Widget

Available on Widget, provided by the WidgetExt extension

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expanded({int flex = 1}) → Expanded

Available on Widget, provided by the ExpandedExtension extension

flexible({int flex = 1}) → Flexible

Available on Widget, provided by the FlexibleExtension extension

getBackgroundColor() → Color
override
getBorderColor() → Color
override
getTextColor() → Color
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDoubleTap(void function()?, {bool ink = false}) → Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

onLongPress(void function()?, {bool ink = false}) → Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

onTap(void function()?, {bool ink = false}) → Widget?

Available on Widget?, provided by the GestureDetectorExtensions extension

paddingAll(double value, {Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingFromViewPadding(ViewPadding padding, double devicePixelRatio, {Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingLTRB(double left, double top, double right, double bottom, {Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0, Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

paddingSymmetric({double vertical = 0.0, double horizontal = 0.0, Key? key}) → Padding

Available on Widget, provided by the PaddingX extension

positionBottom({Key? key, required double bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLeft({Key? key, required double left, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLR({Key? key, required double left, required double right, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionLRTB({Key? key, required double top, required double bottom, required double left, required double right, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionRight({Key? key, required double right, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionTB({Key? key, required double top, required double bottom, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

positionTop({Key? key, required double top, double? width, double? height}) → Positioned

Available on Widget, provided by the PositionedExtensions extension

setOpacity({required double opacity}) → Opacity

Available on Widget, provided by the OpacityExtension extension

toCenter() → Center

Available on Widget, provided by the CenterExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
withTooltip(String message, {Decoration? decoration, double? height, bool? preferBelow, EdgeInsetsGeometry? padding, TextStyle? textStyle, Duration? waitDuration, EdgeInsetsGeometry? margin}) → Widget

Available on Widget, provided by the WidgetsExtension extension

wrapIf(bool test, Widget func(Widget wrappedChild)) → Widget

Available on Widget, provided by the WidgetExt extension

wrap a widget using a Function if test is true

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isValidPlate(String plate) → bool
validate if String is a valid plate number
override