IconMenuButton class

Inheritance

Constructors

IconMenuButton({required IconData icon, required String text, bool extended = false, bool enabled = true, void onPressed()?, Color? color, List<IconMenuItem> subMenu = const []})

Properties

color → Color?
finalinherited
enabled → bool
final
extended → bool
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData
final
onPressed → void Function()?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
final
text → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited