ResponsiveColumn class

Constructors

ResponsiveColumn({double? xxs = 12, double? xs, double? sm, double? md, double? lg, double? xl, double? xxl, double? height, Widget child = nil, Decoration? decoration, Decoration? foregroundDecoration, Alignment? alignment, EdgeInsets? padding, EdgeInsets? margin})
Responsive Column thats have breakpoints for each ScreenTier. If a tier is not specified, its fall down to the next smaller screen tier
const
ResponsiveColumn.all({required double value, double? height, Widget child = nil, Decoration? decoration, Decoration? foregroundDecoration, Alignment? alignment, EdgeInsets? padding, EdgeInsets? margin})
Responsive Column thats have breakpoints for each ScreenTier. Each tier has a default value
factory
ResponsiveColumn.auto({double? xxs = 12, double? xs = 6, double? sm = 4, double? md = 3, double? lg = 3, double? xl = 2, double? xxl = 1, double? height, Widget child = nil, Decoration? decoration, Decoration? foregroundDecoration, Alignment? alignment, EdgeInsets? padding, EdgeInsets? margin})
Responsive Column thats have breakpoints for each ScreenTier. Each tier has a default value
const
ResponsiveColumn.copy(ResponsiveColumn columnSizes, {Widget? child})
Creates a copy of the given ResponsiveColumn with an optional new child.
factory
ResponsiveColumn.full({double? height, Widget child = nil, Decoration? decoration, Decoration? foregroundDecoration, Alignment? alignment, EdgeInsets? padding, EdgeInsets? margin})
Creates a ResponsiveColumn with full width for each screen tier.
factory

Properties

alignment → Alignment?
The alignment of the column.
final
child → Widget
final
decoration → Decoration?
final
foregroundDecoration → Decoration?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
final
lg → double?
final
margin → EdgeInsets?
The margin outside the column.
final
md → double?
final
padding → EdgeInsets?
The padding inside the column.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm → double?
final
xl → double?
final
xs → double?
final
xxl → double?
final
xxs → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited