ScreenTier enum

Represents a Screen size tier (from double extra small to double extra large). The tier is computed by comparing the current screen width to a set of pre-defined screen sizes using the function responsiveValueBy.

Inheritance
Available extensions

Values

xxs → const ScreenTier

Double-Extra small screen.

const ScreenTier(0)
xs → const ScreenTier

Extra small screen.

const ScreenTier(1)
sm → const ScreenTier

Small screen.

const ScreenTier(2)
md → const ScreenTier

Medium screen.

const ScreenTier(3)
lg → const ScreenTier

Large screen.

const ScreenTier(4)
xl → const ScreenTier

Extra Large screen.

const ScreenTier(5)
xxl → const ScreenTier

Double Extra Large screen.

const ScreenTier(6)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
maxWidth → double
Gets the maximum width for the current screen tier.
no setter
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator <(ScreenTier tier) → dynamic
operator <=(ScreenTier tier) → dynamic
operator ==(Object other) → bool
The equality operator.
inherited
operator >(ScreenTier tier) → dynamic
operator >=(ScreenTier tier) → dynamic

Static Properties

breakpoints ↔ ScreenTierMap<double>
The breakpoints for different screen sizes defined by user. if empty, the defaultBreakpoints will be used.
getter/setter pair
defaultBreakpoints → ScreenTierMap<double>
The default breakpoints for different screen sizes. The default breakpoints are as follows:
no setter

Constants

values → const List<ScreenTier>
A constant List of the values in this enum, in order of their declaration.