PageEntry class

Represents a page entry with various properties and methods.

Constructors

PageEntry({String? route, bool showAllToolbarActions = true, required dynamic title, dynamic subtitle, required IconData icon, required List<TabEntry> tabs, IconData? activeIcon, List<Widget>? toolbarItems, String? tooltip, String? actionTooltip, Color? backgroundColor, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, String? actionTitle, void action()?, IconData? actionIcon, List<Widget>? persistentFooterButtons, bool showAppBar = true, void onSearch(String value)?})

Properties

action → void Function()?
The action of the page.
final
actionIcon → IconData?
The action icon of the page.
final
actionTitle → String?
The action title of the page.
final
actionTooltip → String?
The action tooltip of the page.
final
activeIcon → IconData?
The active icon of the page.
final
backgroundColor → Color?
The background color of the page.
final
currentFullRoute → String
Returns the current full route of the page.
no setter
currentTab → TabEntry
Returns the current tab of the page.
no setter
currentTabRoute → String
Returns the current tab route of the page.
no setter
floatingActionButton → Widget?
The floating action button of the page.
final
floatingActionButtonLocation → FloatingActionButtonLocation?
The floating action button location of the page.
final
hashCode → int
The hash code for this object.
no setteroverride
hasTabs → bool
Whether the page has multiple tabs.
no setter
icon → IconData
The icon of the page.
final
isSingleTab → bool
Whether the page has a single tab.
no setter
onSearch → void Function(String value)?
The search callback function.
final
pageRoute → String
Returns the page route.
no setter
persistentFooterButtons → List<Widget>?
The persistent footer buttons of the page.
final
route → String?
The route of the page.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAllToolbarActions → bool
Whether to show all toolbar actions.
final
showAppBar → bool
Whether to show the app bar.
final
subtitle → dynamic
The subtitle of the page.
final
subtitleString → String
Returns the subtitle string.
no setter
subtitleWidget → Widget?
Returns the subtitle widget.
no setter
tabController ↔ TabController?
The tab controller of the page.
getter/setter pair
tabIndex → int
Returns the current tab index.
no setter
tabs → List<TabEntry>
The tabs of the page.
final
title → dynamic
The title of the page.
final
titleString → String
Returns the title string.
no setter
titleWidget → Widget?
Returns the title widget.
no setter
toolbarItems → List<Widget>?
The toolbar items of the page.
final
tooltip → String?
The tooltip of the page.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSearchFunction(int? tabIndex) → void Function(String value)?
Returns the search callback function for the specified tab index.
routeTitle([int tabIndex = 0]) → String
Returns the route title for the specified tab index.
tabFullRoute([int tabIndex = 0]) → String
Returns the full route for the specified tab index.
tabRoute([int tabIndex = 0]) → String
Returns the route for the specified tab index.
tabRouteTitle(int tabIndex) → String
Returns the route title for the specified tab index.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override