TabEntry class

Represents a tab entry with various properties and methods.

Constructors

TabEntry({dynamic title, dynamic subtitle, IconData? icon, required Widget child, void onSearch(String value)?, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, String? route, bool inheritIcon = true})

Properties

child → Widget
The child widget of the tab.
final
floatingActionButton → Widget?
The floating action button of the tab.
final
floatingActionButtonLocation ↔ FloatingActionButtonLocation?
The floating action button location of the tab.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
The icon of the tab.
final
inheritIcon → bool
Whether to inherit the icon from the PageEntry.
final
onSearch → void Function(String value)?
The search callback function for the tab.
final
route → String?
The route of the tab.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → dynamic
The subtitle of the tab.
final
subtitleString → String
Returns the subtitle string of the tab.
no setter
subtitleWidget → Widget?
Returns the subtitle widget of the tab.
no setter
tabRoute → String
Returns the route of the tab.
no setter
title → dynamic
The title of the tab.
final
titleString → String
Returns the title string of the tab.
no setter
titleWidget → Widget?
Returns the title widget of the tab.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited