ValueFieldState<T> class

Inheritance

Constructors

ValueFieldState()

Properties

context → BuildContext
The location in the tree where this widget builds.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textValueSelector → StringList Function(T?)
no setter
useOptionsList → bool
no setter
widget → ValueField<T>
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
allOptions(string v) → Future<List<T>>
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
comparatorFunction(T a, T b) → int
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant ValueField<T> oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
emptySearch(BuildContext context, string searchEntry, string label) → Widget
gera os chips que aparecem nas buscas de SELECTs quando nao tem resultados
equalityFunction(T a, T b) → bool
field(FocusNode fn, TextEditingController textEditingController) → dynamic
initState() → void
Called when this object is inserted into the tree.
override
itemBuilder(BuildContext context, T item, bool isDisabled, bool isSelected) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChanged(T? value, string? textValue) → void
popupFields(BuildContext context, string? title, {DropdownSearchPopupItemBuilder<T>? itemBuilder, IconData? icon, void onIconTap()?, Color? color, IconData? suffixIcon, void onSuffixIconTap()?}) → PopupProps<T>
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
searchOn(T x) → List
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
textSelector(T? e) → string
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
valueSelector(T? e) → string

Operators

operator ==(Object other) → bool
The equality operator.
inherited