SelectExtension<T> extension
- on
-
- Iterable<
T>
- Iterable<
Methods
-
select<
TResult> (TResult selector(T element, int index)) → Iterable< TResult> -
Available on Iterable<
Applies a mapping function to the elements in the iterable, including the index where each element is found.T> , provided by the SelectExtension extension